@@ -10,13 +10,13 @@
 #' @return ARD data frame
 #' @export
 #'
-#' @examplesIf do.call(asNamespace("cardx")$is_pkg_installed, list(pkg = c("broom.helpers", "parameters"), reference_pkg = "cardx"))
+#' @examplesIf do.call(asNamespace("cardx")$is_pkg_installed, list(pkg = c("broom.helpers", "parameters")))
 #' ard_stats_aov(AGE ~ ARM, data = cards::ADSL)
 ard_stats_aov <- function(formula, data, ...) {
   set_cli_abort_call()
 
   # check installed packages ---------------------------------------------------
-  check_pkg_installed(c("broom.helpers", "parameters"), reference_pkg = "cardx")
+  check_pkg_installed(c("broom.helpers", "parameters"))
 
   # check/process inputs -------------------------------------------------------
   check_not_missing(formula)
