@@ -1,4 +1,4 @@
-skip_if_not(is_pkg_installed("broom", reference_pkg = "cardx"))
+skip_if_not(is_pkg_installed("broom"))
 
 test_that("ard_stats_t_test_onesample() works", {
   # first calculate an object to test against
@@ -45,6 +45,19 @@ test_that("ard_stats_t_test_onesample() works", {
       cards::ADSL,
       variables = character(0)
     ),
-    dplyr::tibble()
+    dplyr::tibble() |> cards::as_card()
+  )
+})
+
+test_that("ard_stats_t_test_onesample() follows ard structure", {
+  expect_silent(
+    ard_stats_t_test_onesample(
+      cards::ADSL,
+      variables = AGE,
+      by = ARM,
+      conf.level = 0.9,
+      mu = 1
+    ) |>
+      cards::check_ard_structure()
   )
 })
